@@ -4,11 +4,12 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;
 
 use Acme::CPANAuthors::Register(
     q(AAR) => q(Alessandro Ranellucci),
+    q(AASSAD) => q(Arnaud "Arhuman" Assad),
     q(ABH) => q(Ask Bjørn Hansen),
     q(ABIGAIL) => q(Abigail),
     q(ABRAXXA) => q(Alexander Hartmaier),
@@ -20,8 +21,10 @@ use Acme::CPANAuthors::Register(
     q(AERO) => q(C.H. Kang),
     q(AFLOTT) => q(Adam Flott),
     q(AGENT) => q(agentzh (章亦春)),
+    q(AGJ) => q(Anthony Johnson),
     q(AGRUNDMA) => q(Andy Grundman),
     q(AHARONI) => q(אמיר א׳ אהרוני),
+    q(AIVATURI) => q(Aditya Ivaturi),
     q(AJCT) => q(Adam Taylor),
     q(AJGB) => q(Alex J. G. Burzyński),
     q(ALEX) => q(Alex J. Avriette),
@@ -39,7 +42,7 @@ use Acme::CPANAuthors::Register(
     q(ANDYA) => q(Andy Armstrong),
     q(ANELSON) => q(Andrew Nelson),
     q(ANIRVAN) => q(Anirvan Chatterjee),
-    q(ANNELI) => q(Anneli Cuss),
+    q(ANNELI) => q(Arlen Cuss),
     q(ANSGAR) => q(Ansgar Burchardt),
     q(APOCAL) => q(Apocalypse),
     q(APRIME) => q(Adam Prime),
@@ -49,17 +52,21 @@ use Acme::CPANAuthors::Register(
     q(ARJONES) => q(Andrew Jones),
     q(ARODLAND) => q(Andrew Rodland),
     q(ARPI) => q(Árpád Szász),
+    q(ARTHAS) => q(Michele Beltrame),
     q(ARUNBEAR) => q(Arun Prasaad),
     q(ASH) => q(Ash Berlin),
     q(ASHLEY) => q(Ashley Pond V — 바보 양키스),
     q(ASKADNA) => q(飛鳥 真一郎),
     q(ASPIERS) => q(Adam Spiers),
     q(ATHOMASON) => q(Adam Thomason),
+    q(ATODOROV) => q(Alexander Todorov),
     q(ATOM) => q(Adam J. Foxson),
+    q(AUBERTG) => q(Guillaume Aubert),
     q(AUDREYT) => q(☻ 唐鳳 ☺),
     q(AVAR) => q(Ævar Arnfjörð Bjarmason),
     q(AVUSEROW) => q(Adrian Kreher),
     q(AWNCORP) => q(ANAIO),
+    q(AWWAIID) => q(Brock Wilcox),
     q(AYOUNG) => q(Alan Young),
     q(BARBIE) => q(Barbie),
     q(BAREFOOT) => q(Buddy Burden),
@@ -71,10 +78,12 @@ use Acme::CPANAuthors::Register(
     q(BEANZ) => q(Mark Hindess),
     q(BEPPU) => q(John Beppu),
     q(BERNARD) => q(Benjamin Bernard),
+    q(BESSARABV) => q(Иван Бессарабов),
     q(BEVO) => q(Brendan Beveridge),
     q(BFAIST) => q(Bob Faist),
     q(BGILLS) => q(Brad Gilbert),
     q(BGRAY) => q(Bruce Gray),
+    q(BHANN) => q(Brian Hann),
     q(BIGPRESH) => q(David Precious),
     q(BINGOS) => q(Chris Williams),
     q(BJAKUBSKI) => q(Bartosz Jakubski),
@@ -88,6 +97,7 @@ use Acme::CPANAuthors::Register(
     q(BOKUTIN) => q(Tomohiro Hosaka),
     q(BOMBARELY) => q(Aureliano Bombarely),
     q(BOOK) => q(Philippe Bruhat (BooK)),
+    q(BOWMANBS) => q(Brad Bowman),
     q(BPHILLIPS) => q(Brian Phillips),
     q(BRIANG) => q(brian greenfield),
     q(BRICAS) => q(Brian Cassidy),
@@ -127,14 +137,18 @@ use Acme::CPANAuthors::Register(
     q(CRENZ) => q(Christian Renz),
     q(CROMEDOME) => q(Jason A. Crome),
     q(CRUX) => q(Vladimir Lettiev),
+    q(CSEATON) => q(collin seaton),
+    q(CSIDE) => q(Hiroki Honda),
     q(CUBABIT) => q(Pete Smith),
     q(CVEGA) => q(Casey Vega),
+    q(CWIMMER) => q(Charles A. Wimmer),
     q(DAGOLDEN) => q(David Golden),
-    q(DAM) => q(Дамян Иванов),
+    q(DAKKAR) => q(Gianni Ceccarelli),
     q(DAMOG) => q(David Moreno),
     q(DAMS) => q(Damien Krotkine),
     q(DANAJ) => q(Dana Jacobsen),
     q(DANBOO) => q(Daniel B. Boorstein),
+    q(DANDV) => q(Dan Dascalescu),
     q(DANIEL) => q(Dan Sully),
     q(DANIELM) => q(Daniel Mascarenhas),
     q(DANJOU) => q(Nobuo Danjou),
@@ -149,10 +163,12 @@ use Acme::CPANAuthors::Register(
     q(DBB) => q(Daniel Bolton),
     q(DCHESTER) => q(David Chester),
     q(DDAY) => q(David L. Day),
+    q(DDUMONT) => q(Dominique Dumont),
     q(DELON) => q(Delon Newman),
     q(DERF) => q(Daniel Friesel),
     q(DEXTER) => q(Piotr Roszatycki),
     q(DFH) => q(David F. Houghton),
+    q(DFRETT) => q(Daniel Frett),
     q(DGL) => q(David Leadbeater),
     q(DHOSS) => q(Devin Austin),
     q(DICHI) => q(Mariano Wahlmann),
@@ -160,6 +176,7 @@ use Acme::CPANAuthors::Register(
     q(DKOGAN) => q(Dima Kogan),
     q(DLAMBLEY) => q(Dave Lambley),
     q(DMAKI) => q(Daisuke Maki),
+    q(DMCBRIDE) => q(Darin McBride),
     q(DMITRYNOD) => q(Дмитрий Константинов),
     q(DOGGY) => q(Pan Fan (nightsailer)),
     q(DOHERTY) => q(Mike Doherty),
@@ -177,6 +194,7 @@ use Acme::CPANAuthors::Register(
     q(DRTECH) => q(Clinton Gormley),
     q(DRUOSO) => q(Daniel Ruoso),
     q(DRUXA) => q(Андрей Мищенко),
+    q(DRZIGMAN) => q(Robert Stone),
     q(DUELAFN) => q(Dean Serenevy),
     q(DUFF) => q(Jonathan Scott Duff),
     q(DUKKIE) => q(小塚昌隆),
@@ -188,6 +206,7 @@ use Acme::CPANAuthors::Register(
     q(ECOCODE) => q(Erik Colson),
     q(EDECA) => q(David Cannings),
     q(EDENC) => q(Eden Cardim),
+    q(EDIPRETO) => q(Emmanuel Di Pretoro),
     q(EGILES) => q(Evan Giles),
     q(ELLIOTT) => q(Simon Elliott),
     q(EMAZEP) => q(Emanuele Zeppieri),
@@ -198,10 +217,12 @@ use Acme::CPANAuthors::Register(
     q(EXODIST) => q(Chad Granum),
     q(FANGLY) => q(Florent Angly),
     q(FAYLAND) => q(Fayland 林),
+    q(FCO) => q(Fernando Correa de Oliveira),
     q(FERREIRA) => q(Adriano Ferreira),
+    q(FGA) => q(Fabrice Gabolde),
     q(FLORA) => q(Florian Ragwitz),
     q(FLORIAN) => q(Florian Helmberger),
-    q(FMARIER) => q(François Marier),
+    q(FORWARD) => q(A.Vieth),
     q(FOXCOOL) => q(Alexander Babenko),
     q(FRANCKC) => q(Franck Cuny),
     q(FRANKS) => q(Frank Sheiness),
@@ -210,12 +231,16 @@ use Acme::CPANAuthors::Register(
     q(FRIEDO) => q(Mike Friedman),
     q(FRODWITH) => q(Paul Driver),
     q(FROGGS) => q(Tobias Leich),
+    q(FUJIWARA) => q(FUJIWARA Shunichiro),
     q(FVOX) => q(Junior Moraes),
     q(FWIE) => q(Frank Wiegand),
     q(GAAS) => q(Gisle Aas),
     q(GANGLION) => q(Joel Roth),
     q(GARU) => q(Breno G. de Oliveira),
     q(GBARR) => q(Graham Barr),
+    q(GCJ) => q(Gatlin Cheyenne Johnson),
+    q(GDEY) => q(Gautam Dey),
+    q(GENE) => q(Gene Boggs),
     q(GENEHACK) => q(John SJ Anderson),
     q(GERHARD) => q(Gerhard Gossen),
     q(GETTY) => q(Torsten Raudssus),
@@ -232,6 +257,7 @@ use Acme::CPANAuthors::Register(
     q(GUGOD) => q(劉康民),
     q(GWADEJ) => q(G. Wade Johnson),
     q(GWILLIAMS) => q(Gregory Todd Williams),
+    q(GYPARK) => q(Geunyoung Park),
     q(HAARG) => q(Graham Knop),
     q(HAGGAI) => q(Alan Haggai Alavi),
     q(HALKEYE) => q(Gavin Mogan),
@@ -249,11 +275,15 @@ use Acme::CPANAuthors::Register(
     q(HIRATARA) => q(本間 雅洋 (Masahiro Honma)),
     q(HIROSE) => q(HIROSE Masaaki),
     q(HMA) => q(Henning Manske),
+    q(HMBRAND) => q(H.Merijn Brand),
+    q(HOLLY) => q(Akira Horimoto),
     q(HSW) => q(Sergey Homenkow),
+    q(HWAT) => q(WATANABE Hiroaki),
     q(IBUDAI) => q(Ioana Budai),
     q(ICERIDER) => q(Philip Monsen),
     q(IDOPEREL) => q(עידו פרלמוטר (Ido Perlmuter)),
     q(IKEBE) => q(IKEBE Tomohiro),
+    q(IKEGAMI) => q(ikegami),
     q(ILMARI) => q(Dagfinn Ilmari Mannsåker),
     q(INGY) => q(Ingy döt Net),
     q(IOANR) => q(Ioan Rogers),
@@ -271,12 +301,13 @@ use Acme::CPANAuthors::Register(
     q(JAWNSY) => q(Jonathan Yu),
     q(JBERGER) => q(Joel Berger),
     q(JCOP) => q(Jose Carlos Oliveira Pereira),
-    q(JEEN) => q(Jong-jin Lee),
+    q(JEEN) => q(Jeen Lee),
     q(JERI) => q(Jeremiah Mahler),
     q(JESSE) => q(Jesse Vincent),
     q(JETTERO) => q(Paul Miller),
     q(JFITZ) => q(James FitzGibbon),
     q(JFRIED) => q(Jan Gehring),
+    q(JGAMBLE) => q(John Gamble),
     q(JGOULAH) => q(John Goulah),
     q(JHANNAH) => q(Jay Hannah),
     q(JHELWIG) => q(Jacob Helwig),
@@ -299,11 +330,15 @@ use Acme::CPANAuthors::Register(
     q(JSWARTZ) => q(Jonathan Swartz),
     q(JTPALMER) => q(Jeffrey T. Palmer),
     q(JTRAMMELL) => q(John J. Trammell),
+    q(JUERD) => q(Juerd Waalboer),
     q(JUSTER) => q(Justin Davis),
+    q(JWIELAND) => q(Jason Wieland),
     q(KAARE) => q(Kaare Rasmussen),
     q(KABLAMO) => q(Eric D Johnson),
+    q(KAMIPO) => q(Ryuta Kamizono),
     q(KAORU) => q(Alex Balhatchet),
     q(KARASIK) => q(Dmitry Karasik),
+    q(KARJALA) => q(Αλέξανδρος Καρέλας),
     q(KARMAN) => q(Peter Karman),
     q(KARUPA) => q(Kenta Sato),
     q(KAZEBURO) => q(Masahiro Nagano),
@@ -311,15 +346,17 @@ use Acme::CPANAuthors::Register(
     q(KEEDI) => q(김도형 - Keedi Kim),
     q(KENTARO) => q(Kentaro Kuribayashi),
     q(KENTNL) => q(Kent Fredric),
-    q(KEROYON) => q(keroyonn),
     q(KHAMPTON) => q(Kip Hampton),
+    q(KHUSSEIN) => q(Khaled Hussein),
     q(KIMBREL) => q(Sam Kimbrel),
     q(KIMOTO) => q(Yuki Kimoto),
     q(KITANO) => q(dann),
     q(KIWANAMI) => q(Masashi Sakurai),
+    q(KIXX) => q(Christian-Rolf Grün),
     q(KJETILK) => q(Kjetil Kjernsmo),
     q(KMCGRATH) => q(Kevin McGrath),
     q(KMX) => q(kmx),
+    q(KOJIMAGI) => q(koji takiguchi),
     q(KONOBI) => q(Scott McWhirter),
     q(KOORCHIK) => q(Viktor Tuskyi),
     q(KOST) => q(Vlatko Košturjak),
@@ -330,12 +367,14 @@ use Acme::CPANAuthors::Register(
     q(KUNIYOSHI) => q(Kuniyoshi Kouji),
     q(KVORG) => q(Jan Jona Javoršek),
     q(KWILLIAMS) => q(Ken Williams),
+    q(KYLE) => q(Kyle Hasselbacher),
     q(LACKITA) => q(Colin Williams),
     q(LBROCARD) => q(Léon Brocard),
+    q(LCARMICH) => q(Lee Carmichael),
     q(LECSTOR) => q(Jason Galea),
-    q(LEEDO) => q(Lee Aylward),
     q(LENJAFFE) => q(Len Jaffe),
     q(LEONT) => q(Leon Timmermans),
+    q(LEPREVOST) => q(Felipe Leprevost),
     q(LESPEA) => q(Adam Lesperance),
     q(LETO) => q(Jonathan Leto),
     q(LICHTKIND) => q(Herbert Breunung),
@@ -343,9 +382,12 @@ use Acme::CPANAuthors::Register(
     q(LIMAONE) => q(LIMAONE),
     q(LKUNDRAK) => q(Lubomir Rintel),
     q(LLAP) => q(Leo Lapworth),
+    q(LOGICUS) => q(Simon James Odell),
     q(LOGIE) => q(Logan Bell),
+    q(LOSYME) => q(Loïc TROCHET),
     q(LRR) => q(Luis M Rodríguez-R),
     q(LUKEC) => q(Luke Closs),
+    q(LURKER) => q(Takumi KIMOTO),
     q(MADCAT) => q(Ben van Staveren),
     q(MAESTRO) => q(Geoffrey Darling),
     q(MAKAMAKA) => q(Makamaka Hannyaharamitu),
@@ -376,6 +418,7 @@ use Acme::CPANAuthors::Register(
     q(MEETTYA) => q(Карпич Дмитрий),
     q(MELEZHIK) => q(melezhik),
     q(MELO) => q(Pedro Melo),
+    q(MEMOWE) => q(Mirko Westermeier),
     q(MENDEL) => q(Norbert Buchmüller),
     q(MERIXZON) => q(Magnus Erixzon),
     q(MFONTANI) => q(Marco Fontani),
@@ -396,6 +439,7 @@ use Acme::CPANAuthors::Register(
     q(MMCLERIC) => q(Вячеслав Матюхин),
     q(MMIMS) => q(Marc Mims),
     q(MMUSGROVE) => q(Matthew Musgrove),
+    q(MNUNBERG) => q(Mark (מרדכי) Nunberg),
     q(MONSIEUR) => q(Monsieur Video),
     q(MORITZ) => q(Moritz Lenz),
     q(MORIYA) => q(MORIYA Masaki (守屋 雅樹)),
@@ -406,13 +450,17 @@ use Acme::CPANAuthors::Register(
     q(MRGRIPH) => q(Dmitriy V. Simonov),
     q(MROZ) => q(Ray Mroz),
     q(MRUIZ) => q(Miquel Ruiz Martin),
+    q(MSABRAMO) => q(Marc Abramowitz),
     q(MSCHILLI) => q(Michael Schilli),
     q(MSCHOUT) => q(Michael Schout),
     q(MSCHWERN) => q(Michael G Schwern),
+    q(MSTOCK) => q(Manfred Stock),
     q(MSTRAT) => q(Mark A. Stratman),
+    q(MSTROUT) => q(Matt S Trout),
     q(MUIR) => q(David Muir Sharnoff),
     q(MXEY) => q(Maximilian Gaß),
     q(NCLEATON) => q(Nick Cleaton),
+    q(NEBULOUS) => q(John Lifsey),
     q(NEILB) => q(Neil Bowers),
     q(NEKOKAK) => q(Atsushi Kobayashi),
     q(NEVESENIN) => q(Merten Falk),
@@ -423,6 +471,7 @@ use Acme::CPANAuthors::Register(
     q(NMCFARL) => q(Nathan McFarland),
     q(NORBU) => q(Lenz Gschwendtner),
     q(NOTBENH) => q(ben hengst),
+    q(NOUDARD) => q(Nicolas Oudard),
     q(NPEREZ) => q(Nicholas Perez),
     q(NPLATONOV) => q(Nickolay Platonov),
     q(NUFFIN) => q(יובל קוג'מן (Yuval Kogman)),
@@ -449,7 +498,9 @@ use Acme::CPANAuthors::Register(
     q(PERLISH) => q(seyed hadi hosseini),
     q(PERLOVER) => q(Perlover Developer),
     q(PETDANCE) => q(Andy Lester),
+    q(PEVANS) => q(Paul Evans),
     q(PFISCHER) => q(Pablo Fischer),
+    q(PHAM) => q(Paul Phạm),
     q(PHAYLON) => q(Robert 'phaylon' Sedlacek),
     q(PHILIP) => q(Philip Garrett),
     q(PIN) => q(Dmitri Popov),
@@ -467,21 +518,26 @@ use Acme::CPANAuthors::Register(
     q(PUNYTAN) => q(プニプニ),
     q(PVANDE) => q(Pieter van de Bruggen),
     q(PWES) => q(Przemysław Wesołek),
+    q(PYTHIAN) => q(Pythian Remote DBA),
     q(QIUHW) => q(邱红文),
     q(RAPHINK) => q(Raphaël Pinson),
     q(RBO) => q(Robert Bohne),
     q(RBUELS) => q(Robert Buels),
     q(RCAPUTO) => q(Rocco Caputo),
-    q(REDICAPS) => q(woosley),
+    q(RCL) => q(Robin Clarke),
+    q(REALHOLGI) => q(Holger Eiboeck),
+    q(REDICAPS) => q(woosley xu),
     q(RENTOCRON) => q(Renato Santos de Souza),
     q(REVMISCHA) => q(Mischa Spiegelmock),
     q(RGARCIA) => q(Rafaël Garcia-Suarez),
     q(RGE) => q(Robin Edwards),
+    q(RHAEN) => q(Ulrich Habel),
     q(RHESA) => q(Rhesa Rozendaal),
     q(RHOELZ) => q(Rob Hoelz),
     q(RINTARO) => q(Rintaro Ishizaki),
     q(RIZEN) => q(JT Smith),
     q(RJBS) => q(Ricardo SIGNES),
+    q(RJH) => q(Richard Harris),
     q(RJRAY) => q(Randy J Ray),
     q(RKITOVER) => q(Rafael Kitover),
     q(RKOBES) => q(Randy Kobes (contact brian d foy)),
@@ -489,12 +545,14 @@ use Acme::CPANAuthors::Register(
     q(ROBINS) => q(Robin Smidsrød),
     q(ROBN) => q(Robert Norris),
     q(RODRIGO) => q(Rodrigo de Oliveira Gonzalez),
+    q(ROMANF) => q(Roman F.),
     q(RSIMOES) => q(Richard Simões),
     q(RSRCHBOY) => q(Chris Weyl),
     q(RTHOMPSON) => q(Ryan C. Thompson),
     q(RUBYKAT) => q(Kathryn Andersen),
     q(RURBAN) => q(Reini Urban),
     q(RUSSOZ) => q(Alexei Znamensky),
+    q(RUZ) => q(Руслан У. Закиров),
     q(RWSTAUNER) => q(Randy Stauner),
     q(SABECK) => q(Scott Beck),
     q(SALVA) => q(Salvador Fandiño García),
@@ -527,9 +585,11 @@ use Acme::CPANAuthors::Register(
     q(SILASMONK) => q(Nicholas Bamber),
     q(SIMONW) => q(Simon Wistow),
     q(SIXAPART) => q(Six Apart Ltd.),
+    q(SJN) => q(Salve J. Nilsen),
     q(SKNPP) => q(Sebastian Knapp),
     q(SLU) => q(Søren Lund),
     q(SMUELLER) => q(Steffen Müller),
+    q(SONGMU) => q(Masayuki Matsuki),
     q(SPARKY) => q(Przemysław Iskra),
     q(SPAZM) => q(Andrew Grangaard),
     q(SQUEEK) => q(Squeeks),
@@ -550,6 +610,7 @@ use Acme::CPANAuthors::Register(
     q(SYMKAT) => q(SymKat),
     q(SYOHEX) => q(Syohei Yoshida),
     q(SYP) => q(Станислав Пусеп),
+    q(SYXANASH) => q(Simone Marzulli),
     q(SZABGAB) => q(גאבור סבו - Gábor Szabó),
     q(SZBALINT) => q(Bálint Szilakszi),
     q(TADAM) => q(Yury Zavarin),
@@ -571,6 +632,7 @@ use Acme::CPANAuthors::Register(
     q(TOKUHIROM) => q(MATSUNO★Tokuhiro),
     q(TOMELIAZ) => q(Tom Eliaz),
     q(TOMFAHLE) => q(Thomas Fahle),
+    q(TOMHUKINS) => q(Tom Hukins),
     q(TOMITA) => q(Naoki Tomita (tomi-ru)),
     q(TONYC) => q(Tony Cook),
     q(TRCJR) => q(Theodore Robert Campbell Jr),
@@ -578,12 +640,14 @@ use Acme::CPANAuthors::Register(
     q(TSUCCHI) => q(Takuya Tsuchida),
     q(TYPESTER) => q(Daisuke Murase),
     q(UASI) => q(Tomoki Aonuma),
+    q(UKSZA) => q(Łukasz Mądrzycki),
     q(UNDEF) => q(Сергей Засенко),
     q(UNOBE) => q(David Romano),
     q(USUALOMA) => q(Taku Amano),
     q(VDG) => q(Valentin D Guillois),
     q(VESELOSKY) => q(Vincent E. Veselosky),
     q(VKON) => q(Vadim Konovalov),
+    q(VOEGELAS) => q(Andreas Vögele),
     q(VOJ) => q(Jakob Voß),
     q(VOVKASM) => q(Vladimir Timofeev),
     q(VTI) => q(Вячеслав Тихановский),
@@ -591,6 +655,7 @@ use Acme::CPANAuthors::Register(
     q(VVU) => q(Alex White (wu)),
     q(WARRINGD) => q(David Warring),
     q(WARTHURT) => q(Wayne A. Arthurton),
+    q(WHITNEY) => q(Whitney Jackson),
     q(WINTER) => q(Becca Turner),
     q(WOLDRICH) => q(Magnus Woldrich),
     q(WOLFSAGE) => q(Matthew Horsfall (alh)),
@@ -622,10 +687,11 @@ use Acme::CPANAuthors::Register(
     q(ZDK) => q(Warachet Samtalee),
     q(ZEFRAM) => q(Andrew Main (Zefram)),
     q(ZENTOOO) => q(Naosuke Yokoe),
-    q(ZERO) => q(Oleg Alistratov),
+    q(ZERO) => q(Олег Алистратов),
     q(ZEROHP) => q(Eric Clark),
     q(ZIGOROU) => q(Toru Yamaguchi),
     q(ZOUL) => q(Tomáš Znamenáček),
+    q(ZPMORGAN) => q(Zach Morgan),
     q(ZWON) => q(Pavel Shaydo),
     q(ZZZ) => q(Alexandr Gomoliako),
 );
